@@ -8,6 +8,7 @@
 /// # use cursive::event::Event;
 /// # use cursive::view::Nameable;
 /// let mut root = cursive::default();
+/// # root.set_theme(better_theme());
 /// root.add_fullscreen_layer(
 ///     LinearLayout::vertical()
 ///         .child(
@@ -51,6 +52,7 @@ macro_rules! report_error {
 /// }.on_submit(|v, _| v.quit());
 /// 
 /// let mut root = cursive::default();
+/// # root.set_theme(better_theme());
 /// root.add_fullscreen_layer(Dialog::around(sv).title("Select View"));
 /// root.run();
 /// ```
@@ -58,7 +60,7 @@ macro_rules! report_error {
 macro_rules! select_view {
     ($($label:expr => $item:expr), *) => {
         {
-            use cursive_core::views::SelectView;
+            use cursive::views::SelectView;
             let mut temp_sv = SelectView::new();
             $(
                 temp_sv.add_item($label, $item);
@@ -75,6 +77,7 @@ macro_rules! select_view {
 /// # use cursive::views::{TextView, EditView};
 /// # use cursive_extras::*;
 /// let mut root = cursive::default();
+/// # root.set_theme(better_theme());
 /// root.add_fullscreen_layer(
 ///     settings!(
 ///         "Settings Example", // title
@@ -89,7 +92,7 @@ macro_rules! select_view {
 macro_rules! settings {
     ($title:expr, $save_cb:expr, $($view:expr), *) => {
         {
-            use cursive_core::views::{Dialog, LinearLayout};
+            use cursive::views::{Dialog, LinearLayout};
             Dialog::around(
                 LinearLayout::vertical()
                 $(
@@ -110,6 +113,7 @@ macro_rules! settings {
 /// # use cursive_extras::*;
 /// # use cursive::views::{Dialog, TextView};
 /// let mut root = cursive::default();
+/// # root.set_theme(better_theme());
 /// root.add_fullscreen_layer(
 ///     Dialog::around(
 ///         hlayout!(
@@ -125,7 +129,7 @@ macro_rules! settings {
 macro_rules! hlayout {
     ($($view:expr), *) => {
         {
-            use cursive_core::views::LinearLayout;
+            use cursive::views::LinearLayout;
             LinearLayout::horizontal()
             $(
                 .child($view)
@@ -141,6 +145,7 @@ macro_rules! hlayout {
 /// # use cursive_extras::*;
 /// # use cursive::views::{Dialog, TextView};
 /// let mut root = cursive::default();
+/// # root.set_theme(better_theme());
 /// root.add_fullscreen_layer(
 ///     Dialog::around(
 ///         vlayout!(
@@ -156,7 +161,7 @@ macro_rules! hlayout {
 macro_rules! vlayout {
     ($($view:expr), *) => {
         {
-            use cursive_core::views::LinearLayout;
+            use cursive::views::LinearLayout;
             LinearLayout::vertical()
             $(
                 .child($view)
